@@ -70,7 +70,11 @@ def test_run_sweep_executes_circuit(adonis_sampler, circuit, iqm_metadata):
     client = mock(IQMClient)
     run_id = uuid.uuid4()
     run_result = RunResult(status=Status.READY, measurements=[{'some stuff': [[0], [1]]}], metadata=iqm_metadata)
-    when(client).submit_circuits(ANY, qubit_mapping=ANY, settings=ANY, shots=ANY).thenReturn(run_id)
+    when(client).submit_circuits(ANY,
+                                 qubit_mapping=ANY,
+                                 settings=ANY,
+                                 calibration_set_id=ANY,
+                                 shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
 
     adonis_sampler._client = client
@@ -96,7 +100,11 @@ def test_run_sweep_executes_circuit_without_settings(adonis_sampler_without_sett
     client = mock(IQMClient)
     run_id = uuid.uuid4()
     run_result = RunResult(status=Status.READY, measurements=[{'some stuff': [[0], [1]]}], metadata=iqm_metadata)
-    when(client).submit_circuits(ANY, qubit_mapping=ANY, settings=None, shots=ANY).thenReturn(run_id)
+    when(client).submit_circuits(ANY,
+                                 qubit_mapping=ANY,
+                                 settings=None,
+                                 calibration_set_id=ANY,
+                                 shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
 
     adonis_sampler_without_settings._client = client
@@ -110,7 +118,11 @@ def test_run_sweep_with_parameter_sweep(adonis_sampler_without_settings, iqm_met
     run_id = uuid.uuid4()
     run_result = RunResult(
         status=Status.READY, measurements=[{'some stuff': [[0]]}, {'some stuff': [[1]]}], metadata=iqm_metadata)
-    when(client).submit_circuits(ANY, qubit_mapping=ANY, settings=ANY, shots=ANY).thenReturn(run_id)
+    when(client).submit_circuits(ANY,
+                                 qubit_mapping=ANY,
+                                 settings=ANY,
+                                 calibration_set_id=ANY,
+                                 shots=ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
     qubit_1 = cirq.NamedQubit('QB1')
     qubit_2 = cirq.NamedQubit('QB2')
@@ -139,7 +151,7 @@ def test_credentials_are_passed_to_client():
     assert sampler._client._credentials.password == user_auth_args['password']
 
 
-def test_client_close():
+def test_close_client():
     user_auth_args = {
         'auth_server_url': 'https://fake.auth.server.com',
         'username': 'fake-username',
